==> jaxrs-ri-2.4.1-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/DefaultRespondingContext.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server;

import org.glassfish.jersey.process.internal.ChainableStage;
import org.glassfish.jersey.process.internal.RequestScoped;
import org.glassfish.jersey.process.internal.Stage;
import org.glassfish.jersey.process.internal.Stages;
import org.glassfish.jersey.server.internal.process.RespondingContext;

import com.google.common.base.Function;

/**
 * Default implementation of the request-scoped
 * {@link org.glassfish.jersey.server.internal.process.RespondingContext responding context}.
 *
 * @author Marek Potociar (marek.potociar at oracle.com)
 */
@RequestScoped
class DefaultRespondingContext implements RespondingContext {

    private Stage<ContainerResponse> rootStage;

    @Override
    public void push(Function<ContainerResponse, ContainerResponse> responseTransformation) {
        rootStage = (rootStage == null)
                ? new Stages.LinkedStage<ContainerResponse>(responseTransformation)
                : new Stages.LinkedStage<ContainerResponse>(responseTransformation, rootStage);
    }

    @Override
    public void push(final ChainableStage<ContainerResponse> stage) {
        if (rootStage != null) {
            stage.setDefaultNext(rootStage);
        }

        rootStage = stage;
    }

    @Override
    public Stage<ContainerResponse> createRespondingRoot() {
        return rootStage;
    }
}

==> jaxrs-ri-2.7-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/DefaultRespondingContext.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server;

import org.glassfish.jersey.process.internal.ChainableStage;
import org.glassfish.jersey.process.internal.RequestScoped;
import org.glassfish.jersey.process.internal.Stage;
import org.glassfish.jersey.process.internal.Stages;
import org.glassfish.jersey.server.internal.process.RespondingContext;

import jersey.repackaged.com.google.common.base.Function;

/**
 * Default implementation of the request-scoped
 * {@link org.glassfish.jersey.server.internal.process.RespondingContext responding context}.
 *
 * @author Marek Potociar (marek.potociar at oracle.com)
 */
@RequestScoped
class DefaultRespondingContext implements RespondingContext {

    private Stage<ContainerResponse> rootStage;

    @Override
    public void push(Function<ContainerResponse, ContainerResponse> responseTransformation) {
        rootStage = (rootStage == null)
                ? new Stages.LinkedStage<ContainerResponse>(responseTransformation)
                : new Stages.LinkedStage<ContainerResponse>(responseTransformation, rootStage);
    }

    @Override
    public void push(final ChainableStage<ContainerResponse> stage) {
        if (rootStage != null) {
            stage.setDefaultNext(rootStage);
        }

        rootStage = stage;
    }

    @Override
    public Stage<ContainerResponse> createRespondingRoot() {
        return rootStage;
    }
}
